<?php
/**
 * SEO metabox.
 *
 * Metabox Name: SEO
 * Description: Add Search Engine Optimization managing to pages.
 * Version: 0.1
 * Author: Infomaker Scandinavia AB
 * Author URI: http://infomaker.se
 */
namespace EwTools\Metaboxes;

use EwTools\Models\Page;
use EwTools\Support\Str;
use EwTools\Admin\Metabox;
use EwTools\Twig\View;
use WP_Post;

/**
 * SEO
 *
 * @link    http://infomaker.se
 * @package Everyware\Metaboxes
 * @since   Everyware\Metaboxes\SEO 0.1
 */
class SEO extends Metabox {
	
	/**
	 * postmeta id
	 * @see Metabox::$postmeta_id
	 *
	 * @var string
	 */
	public static $postmeta_id = 'ew_seo_box';
	
	/**
	 * metabox id
	 * @see Metabox::$meta_box_id
	 *
	 * @var string
	 */
	protected $meta_box_id = 'ew-seo-box';
    
    /**
     * Twig-template to use
     *
     * @var string
     */
    protected $template_path = '@tools/metaboxes/seo';
	
	/**
	 * Metabox fields:
	 * Contains fields to change title and description of pages
	 * and to keep crawlers from indexing pages or follow their links
	 * 
	 * @var array
	 */
	protected $fields = [
		'title' => '',
		'description' => '',
		'noindex' => false,
		'nofollow' => false
	];
	
	/**
	 * SEO constructor.
	 *
	 * @param string $title
	 *
	 * @since 0.1
	 */
	public function __construct( $title= 'SEO' ) {
	    $this->setMetaboxData(__FILE__);
	    parent::__construct($title);
	}
    
    /**
     * Retrieve content for the "robot" meta tag
     * Ex. <meta name="robots" content="noindex, nofollow">
     *
     * @param Page $page
     *
     * @since 0.1
     * @return string
     */
	public static function getRobotMeta( Page $page ) {
		$robot_meta = static::getMetaData( $page, 'noindex' ) ? 'noindex': 'index';
		$follow_meta = static::getMetaData( $page, 'nofollow' ) ? 'nofollow' : 'follow';
		
		return Str::append($follow_meta, $robot_meta, ',');
	}
	
	/**
	 * Render the metabox form
	 *
	 * @param string $view_data
	 *
	 * @since 0.1
	 * @return void
	 */
	protected function edit( $view_data ) {
        $this->view('form', $view_data);
	}
}