<?php namespace EwTools\Twig;

use RecursiveDirectoryIterator;
use RecursiveFilterIterator;
use RecursiveIterator;
use RecursiveIteratorIterator;

/**
 * PathFilter
 *
 * @link    http://infomaker.se
 * @package EwTools\Twig
 * @since   EwTools\Twig\PathFilter 0.1
 */
class PathFilter extends RecursiveFilterIterator {
    
    /**
     * Contains an array of files and folders to exclude
     *
     * @var array
     */
    protected $exclude;
    
    /**
     * PathFilter constructor.
     *
     * @since 0.1
     *
     * @param \RecursiveIterator $iterator
     * @param array              $exclude
     */
    public function __construct( RecursiveIterator $iterator, array $exclude = [] ) {
        parent::__construct( $iterator );
        $this->exclude = $exclude;
    }
    
    /**
     * No documentation yet
     *
     * @todo  Add documentation
     * @since 0.1
     * @return bool
     */
    public function accept() {
        return ( $this->isDir() && ! in_array( $this->getFilename(), $this->exclude ) );
    }
    
    /**
     * No documentation yet
     *
     * @todo  Add documentation
     * @since 0.1
     * @return PathFilter
     */
    public function getChildren() {
        return new static( $this->getInnerIterator()->getChildren(), $this->exclude );
    }
    
    /**
     * The filtered list in recursive order
     *
     * @since 0.1
     * @return RecursiveIteratorIterator
     */
    public function filtered() {
        return new RecursiveIteratorIterator( $this );
    }
    
    /**
     * Function to setup iterator from en absolute path
     *
     * @param string $path
     * @param array $exclude
     *
     * @since 0.1
     * @return static
     */
    public static function setupFromPath( $path, array $exclude = []) {
        return new static(new RecursiveDirectoryIterator( $path ), $exclude);
    }
}